==> client-lib-1.4.3-sources.jar: io/baltoro/domain/BaltoroInstance.java <==
package io.baltoro.domain;

import java.sql.Timestamp;

public class BaltoroInstance
{
	private String uuid;
	private String appUuid;
	private String state;
	private String clusterPath;
	private String hostAddress;
	private String remoteAddress;
	private int threadCount;
	private int cpuPercent;
	private int memoryGB;
	private Timestamp lastHeartBeatOn;
	private String createdBy;
	private Timestamp startedOn;
	private Timestamp createdOn;
	private boolean running;
	
	
	
	
	public String getUuid()
	{
		return uuid;
	}
	public void setUuid(String uuid)
	{
		this.uuid = uuid;
	}
	public String getAppUuid()
	{
		return appUuid;
	}
	public void setAppUuid(String appUuid)
	{
		this.appUuid = appUuid;
	}
	
	
	
	
	
	public String getCreatedBy()
	{
		return createdBy;
	}
	public void setCreatedBy(String createdBy)
	{
		this.createdBy = createdBy;
	}
	
	
	public String getState() 
	{
		return state;
	}
	public void setState(String state) 
	{
		this.state = state;
	}
	public String getRemoteAddress()
	{
		return remoteAddress;
	}
	public void setRemoteAddress(String remoteAddress)
	{
		this.remoteAddress = remoteAddress;
	}
	public int getThreadCount()
	{
		return threadCount;
	}
	public void setThreadCount(int threadCount)
	{
		this.threadCount = threadCount;
	}
	public String getHostAddress()
	{
		return hostAddress;
	}
	public void setHostAddress(String hostAddress)
	{
		this.hostAddress = hostAddress;
	}
	public int getCpuPercent()
	{
		return cpuPercent;
	}
	public void setCpuPercent(int cpuPercent)
	{
		this.cpuPercent = cpuPercent;
	}
	public int getMemoryGB()
	{
		return memoryGB;
	}
	public void setMemoryGB(int memoryGB)
	{
		this.memoryGB = memoryGB;
	}
	public Timestamp getLastHeartBeatOn()
	{
		return lastHeartBeatOn;
	}
	public void setLastHeartBeatOn(Timestamp lastHeartBeatOn)
	{
		this.lastHeartBeatOn = lastHeartBeatOn;
	}
	public Timestamp getStartedOn()
	{
		return startedOn;
	}
	public void setStartedOn(Timestamp startedOn)
	{
		this.startedOn = startedOn;
	}
	public Timestamp getCreatedOn()
	{
		return createdOn;
	}
	public void setCreatedOn(Timestamp createdOn)
	{
		this.createdOn = createdOn;
	}
	public boolean isRunning()
	{
		return running;
	}
	public void setRunning(boolean running)
	{
		this.running = running;
	}
	public String getClusterPath()
	{
		return clusterPath;
	}
	public void setClusterPath(String clusterPath)
	{
		this.clusterPath = clusterPath;
	}
	
	
	
	
	
	
}

==> client-lib-2.1.0-sources.jar: io/baltoro/domain/BaltoroInstance.java <==
package io.baltoro.domain;

import java.sql.Timestamp;

public class BaltoroInstance
{
	
	private String uuid;
	private String appUuid;
	private String state;
	private String serviceName;
	private String hostAddress;
	private String remoteAddress;
	private int threadCount;
	private int cpuPercent;
	private int memoryGB;
	private Timestamp lastHeartBeatOn;
	private String createdBy;
	private Timestamp startedOn;
	private Timestamp createdOn;
	private boolean running;
	
	
	
	
	public String getUuid()
	{
		return uuid;
	}
	public void setUuid(String uuid)
	{
		this.uuid = uuid;
	}
	public String getAppUuid()
	{
		return appUuid;
	}
	public void setAppUuid(String appUuid)
	{
		this.appUuid = appUuid;
	}
	
	
	
	
	
	public String getCreatedBy()
	{
		return createdBy;
	}
	public void setCreatedBy(String createdBy)
	{
		this.createdBy = createdBy;
	}
	
	
	public String getState() 
	{
		return state;
	}
	public void setState(String state) 
	{
		this.state = state;
	}
	public String getRemoteAddress()
	{
		return remoteAddress;
	}
	public void setRemoteAddress(String remoteAddress)
	{
		this.remoteAddress = remoteAddress;
	}
	public int getThreadCount()
	{
		return threadCount;
	}
	public void setThreadCount(int threadCount)
	{
		this.threadCount = threadCount;
	}
	public String getHostAddress()
	{
		return hostAddress;
	}
	public void setHostAddress(String hostAddress)
	{
		this.hostAddress = hostAddress;
	}
	public int getCpuPercent()
	{
		return cpuPercent;
	}
	public void setCpuPercent(int cpuPercent)
	{
		this.cpuPercent = cpuPercent;
	}
	public int getMemoryGB()
	{
		return memoryGB;
	}
	public void setMemoryGB(int memoryGB)
	{
		this.memoryGB = memoryGB;
	}
	public Timestamp getLastHeartBeatOn()
	{
		return lastHeartBeatOn;
	}
	public void setLastHeartBeatOn(Timestamp lastHeartBeatOn)
	{
		this.lastHeartBeatOn = lastHeartBeatOn;
	}
	public Timestamp getStartedOn()
	{
		return startedOn;
	}
	public void setStartedOn(Timestamp startedOn)
	{
		this.startedOn = startedOn;
	}
	public Timestamp getCreatedOn()
	{
		return createdOn;
	}
	public void setCreatedOn(Timestamp createdOn)
	{
		this.createdOn = createdOn;
	}
	public boolean isRunning()
	{
		return running;
	}
	public void setRunning(boolean running)
	{
		this.running = running;
	}
	public String getServiceName()
	{
		return serviceName;
	}
	public void setServiceName(String serviceName)
	{
		this.serviceName = serviceName;
	}
	
	
	
	
	
	
}
